@@ -37,6 +37,7 @@
 #include "commands/error_constants.h"
 #include "event_util.h"
 #include "fmt/format.h"
+#include "fmt/ostream.h"
 #include "io_util.h"
 #include "logging.h"
 #include "rocksdb/write_batch.h"
@@ -62,7 +63,9 @@ FeedSlaveThread::FeedSlaveThread(Server *srv, redis::Connection *conn, rocksdb::
       next_repl_seq_(next_repl_seq),
       req_(srv),
       max_delay_bytes_(srv->GetConfig()->max_replication_delay_bytes),
-      max_delay_updates_(srv->GetConfig()->max_replication_delay_updates) {}
+      max_delay_updates_(srv->GetConfig()->max_replication_delay_updates),
+      max_replication_lag_(srv->GetConfig()->max_replication_lag),
+      send_timeout_ms_(srv->GetConfig()->replication_send_timeout_ms) {}
 
 Status FeedSlaveThread::Start() {
   auto s = util::CreateThread("feed-replica", [this] {
@@ -75,7 +78,7 @@ Status FeedSlaveThread::Start() {
     pthread_sigmask(SIG_BLOCK, &mask, &omask);
     auto s = util::SockSend(conn_->GetFD(), redis::RESP_OK, conn_->GetBufferEvent());
     if (!s.IsOK()) {
-      error("failed to send OK response to the replica: {}", s.Msg());
+      ERROR("failed to send OK response to the replica: {}", s.Msg());
       return;
     }
     this->loop();
@@ -97,12 +100,12 @@ Status FeedSlaveThread::Start() {
 
 void FeedSlaveThread::Stop() {
   stop_ = true;
-  warn("Slave thread was terminated, would stop feeding the slave: {}", conn_->GetAddr());
+  WARN("Slave thread was terminated, would stop feeding the slave: {}", conn_->GetAddr());
 }
 
 void FeedSlaveThread::Join() {
   if (auto s = util::ThreadJoin(t_); !s) {
-    warn("Slave thread operation failed: {}", s.Msg());
+    WARN("Slave thread operation failed: {}", s.Msg());
   }
 }
 
@@ -111,7 +114,7 @@ void FeedSlaveThread::checkLivenessIfNeed() {
   const auto ping_command = redis::BulkString("ping");
   auto s = util::SockSend(conn_->GetFD(), ping_command, conn_->GetBufferEvent());
   if (!s.IsOK()) {
-    error("Ping slave [{}] err: {}, would stop the thread", conn_->GetAddr(), s.Msg());
+    ERROR("Ping slave [{}] err: {}, would stop the thread", conn_->GetAddr(), s.Msg());
     Stop();
   }
 }
@@ -127,7 +130,7 @@ void FeedSlaveThread::readCallback(bufferevent *bev, [[maybe_unused]] void *ctx)
   auto input = bufferevent_get_input(bev);
   auto s = req_.Tokenize(input);
   if (!s.IsOK()) {
-    error("[replication] failed to tokenize request: {}", s.Msg());
+    ERROR("[replication] failed to tokenize request: {}", s.Msg());
     return;
   }
 
@@ -136,13 +139,13 @@ void FeedSlaveThread::readCallback(bufferevent *bev, [[maybe_unused]] void *ctx)
   for (const auto &command : *commands) {
     // Validate replconf ack command format
     if (command.size() != 3 || command[0] != "replconf" || command[1] != "ack") {
-      error("[replication] invalid command: {}", util::StringJoin(command, std::string_view(",")));
+      ERROR("[replication] invalid command: {}", util::StringJoin(command, std::string_view(",")));
       continue;
     }
 
     auto seq = ParseInt<rocksdb::SequenceNumber>(command[2], 10);
     if (!seq) {
-      error("[replication] invalid sequence number: {}", util::StringJoin(command, std::string_view(",")));
+      ERROR("[replication] invalid sequence number: {}", util::StringJoin(command, std::string_view(",")));
       continue;
     }
 
@@ -183,8 +186,23 @@ void FeedSlaveThread::loop() {
   while (!IsStopped()) {
     auto curr_seq = next_repl_seq_.load();
 
+    // Check replication lag - disconnect slow consumers before WAL is exhausted
+    // Skip check if max_replication_lag_ is 0 (feature disabled)
+    if (max_replication_lag_ > 0) {
+      auto latest_seq = srv_->storage->LatestSeqNumber();
+      if (latest_seq > curr_seq) {
+        auto lag = static_cast<int64_t>(latest_seq - curr_seq);
+        if (lag > max_replication_lag_) {
+          ERROR("Replication lag {} exceeds max allowed {} for slave {}:{}, disconnecting to prevent WAL exhaustion",
+                lag, max_replication_lag_, conn_->GetAnnounceIP(), conn_->GetListeningPort());
+          Stop();
+          return;
+        }
+      }
+    }
+
     if (!iter_ || !iter_->Valid()) {
-      if (iter_) info("WAL was rotated, would reopen again");
+      if (iter_) INFO("WAL was rotated, would reopen again");
       if (!srv_->storage->WALHasNewData(curr_seq) || !srv_->storage->GetWALIter(curr_seq, &iter_).IsOK()) {
         iter_ = nullptr;
         usleep(yield_microseconds);
@@ -195,7 +213,7 @@ void FeedSlaveThread::loop() {
     // iter_ would be always valid here
     auto batch = iter_->GetBatch();
     if (batch.sequence != curr_seq) {
-      error(
+      ERROR(
           "Fatal error encountered, WAL iterator is discrete, some seq might be lost, sequence {} expected, but got {}",
           curr_seq, batch.sequence);
       Stop();
@@ -220,10 +238,12 @@ void FeedSlaveThread::loop() {
         batches_bulk += redis::BulkString("_getack");
       }
 
-      // Send entire bulk which contain multiple batches
-      auto s = util::SockSend(conn_->GetFD(), batches_bulk, conn_->GetBufferEvent());
+      // Send entire bulk which contain multiple batches with timeout
+      // This prevents blocking indefinitely on slow consumers
+      auto s = util::SockSendWithTimeout(conn_->GetFD(), batches_bulk, conn_->GetBufferEvent(), send_timeout_ms_);
       if (!s.IsOK()) {
-        error("Write error while sending batch to slave: {}. batches: 0x{}", s.Msg(), util::StringToHex(batches_bulk));
+        ERROR("Write error while sending batch to slave {}:{}: {}. batch_size={}", conn_->GetAnnounceIP(),
+              conn_->GetListeningPort(), s.Msg(), batches_bulk.size());
         Stop();
         return;
       }
@@ -258,10 +278,15 @@ void ReplicationThread::CallbacksStateMachine::ConnEventCB(bufferevent *bev, int
     return;
   }
   if (events & (BEV_EVENT_ERROR | BEV_EVENT_EOF)) {
-    error("[replication] connection error/eof, reconnect the master");
-    // Wait a bit and reconnect
+    ERROR("[replication] connection error/eof, reconnect the master");
+    // Wait with exponential backoff before reconnecting
+    constexpr int kMaxBackoffSeconds = 60;
+    constexpr int kMaxShiftBits = 6;  // Cap shift to avoid UB; 2^6 = 64 then clamped to 60
     repl_->repl_state_.store(kReplConnecting, std::memory_order_relaxed);
-    std::this_thread::sleep_for(std::chrono::seconds(1));
+    int attempts = repl_->reconnect_attempts_.fetch_add(1, std::memory_order_relaxed);
+    int backoff_secs = std::min(1 << std::min(attempts, kMaxShiftBits), kMaxBackoffSeconds);
+    WARN("[replication] waiting {} seconds before reconnecting (attempt {})", backoff_secs, attempts + 1);
+    std::this_thread::sleep_for(std::chrono::seconds(backoff_secs));
     Stop();
     Start();
   }
@@ -280,7 +305,7 @@ void ReplicationThread::CallbacksStateMachine::SetWriteCB(bufferevent *bev, buff
 void ReplicationThread::CallbacksStateMachine::ReadWriteCB(bufferevent *bev) {
 LOOP_LABEL:
   assert(handler_idx_ <= handlers_.size());
-  debug("[replication] Execute handler[{}]", getHandlerName(handler_idx_));
+  DEBUG("[replication] Execute handler[{}]", getHandlerName(handler_idx_));
   auto st = getHandlerFunc(handler_idx_)(repl_, bev);
   repl_->last_io_time_secs_.store(util::GetTimeStamp(), std::memory_order_relaxed);
   switch (st) {
@@ -307,11 +332,11 @@ LOOP_LABEL:
     case CBState::RESTART:  // state that can be retried some time later
       Stop();
       if (repl_->stop_flag_) {
-        info("[replication] Wouldn't restart while the replication thread was stopped");
+        INFO("[replication] Wouldn't restart while the replication thread was stopped");
         break;
       }
       repl_->repl_state_.store(kReplConnecting, std::memory_order_relaxed);
-      info("[replication] Retry in 10 seconds");
+      INFO("[replication] Retry in 10 seconds");
       std::this_thread::sleep_for(std::chrono::seconds(10));
       Start();
   }
@@ -341,7 +366,7 @@ void ReplicationThread::CallbacksStateMachine::Start() {
     last_connect_timestamp = util::GetTimeStampMS();
     auto cfd = util::SockConnect(repl_->host_, repl_->port_, repl_->srv_->GetConfig()->replication_connect_timeout_ms);
     if (!cfd) {
-      error("[replication] Failed to connect the master, err: {}", cfd.Msg());
+      ERROR("[replication] Failed to connect the master, err: {}", cfd.Msg());
       continue;
     }
 #ifdef ENABLE_OPENSSL
@@ -349,7 +374,7 @@ void ReplicationThread::CallbacksStateMachine::Start() {
     if (repl_->srv_->GetConfig()->tls_replication) {
       ssl = SSL_new(repl_->srv_->ssl_ctx.get());
       if (!ssl) {
-        error("Failed to construct SSL structure for new connection: {}", fmt::streamed(SSLErrors{}));
+        ERROR("Failed to construct SSL structure for new connection: {}", fmt::streamed(SSLErrors{}));
         evutil_closesocket(*cfd);
         return;
       }
@@ -365,7 +390,7 @@ void ReplicationThread::CallbacksStateMachine::Start() {
       if (ssl) SSL_free(ssl);
 #endif
       close(*cfd);
-      error("[replication] Failed to create the event socket");
+      ERROR("[replication] Failed to create the event socket");
       continue;
     }
 #ifdef ENABLE_OPENSSL
@@ -427,9 +452,9 @@ Status ReplicationThread::Start(std::function<bool()> &&pre_fullsync_cb, std::fu
   // Clean synced checkpoint from old master because replica starts to follow new master
   auto s = rocksdb::DestroyDB(srv_->GetConfig()->sync_checkpoint_dir, rocksdb::Options());
   if (!s.ok()) {
-    warn("Can't clean synced checkpoint from master, error: {}", s.ToString());
+    WARN("Can't clean synced checkpoint from master, error: {}", s.ToString());
   } else {
-    warn("Clean old synced checkpoint successfully");
+    WARN("Clean old synced checkpoint successfully");
   }
 
   // cleanup the old backups, so we can start replication in a clean state
@@ -449,9 +474,9 @@ void ReplicationThread::Stop() {
   stop_flag_ = true;  // Stopping procedure is asynchronous,
                       // handled by timer
   if (auto s = util::ThreadJoin(t_); !s) {
-    warn("Replication thread operation failed: {}", s.Msg());
+    WARN("Replication thread operation failed: {}", s.Msg());
   }
-  info("[replication] Stopped");
+  INFO("[replication] Stopped");
 }
 
 /*
@@ -465,7 +490,7 @@ void ReplicationThread::Stop() {
 void ReplicationThread::run() {
   base_ = event_base_new();
   if (base_ == nullptr) {
-    error("[replication] Failed to create new ev base");
+    ERROR("[replication] Failed to create new ev base");
     return;
   }
   psync_steps_.Start();
@@ -481,7 +506,7 @@ void ReplicationThread::run() {
 
 ReplicationThread::CBState ReplicationThread::authWriteCB(bufferevent *bev) {
   SendString(bev, redis::ArrayOfBulkStrings({"AUTH", srv_->GetConfig()->masterauth}));
-  info("[replication] Auth request was sent, waiting for response");
+  INFO("[replication] Auth request was sent, waiting for response");
   repl_state_.store(kReplSendAuth, std::memory_order_relaxed);
   return CBState::NEXT;
 }
@@ -494,17 +519,17 @@ ReplicationThread::CBState ReplicationThread::authReadCB(bufferevent *bev) {  //
   if (!line) return CBState::AGAIN;
   if (!ResponseLineIsOK(line.View())) {
     // Auth failed
-    error("[replication] Auth failed: {}", line.get());
+    ERROR("[replication] Auth failed: {}", line.get());
     return CBState::RESTART;
   }
-  info("[replication] Auth response was received, continue...");
+  INFO("[replication] Auth response was received, continue...");
   return CBState::NEXT;
 }
 
 ReplicationThread::CBState ReplicationThread::checkDBNameWriteCB(bufferevent *bev) {
   SendString(bev, redis::ArrayOfBulkStrings({"_db_name"}));
   repl_state_.store(kReplCheckDBName, std::memory_order_relaxed);
-  info("[replication] Check db name request was sent, waiting for response");
+  INFO("[replication] Check db name request was sent, waiting for response");
   return CBState::NEXT;
 }
 
@@ -515,19 +540,19 @@ ReplicationThread::CBState ReplicationThread::checkDBNameReadCB(bufferevent *bev
 
   if (line[0] == '-') {
     if (isRestoringError(line.View())) {
-      warn("The master was restoring the db, retry later");
+      WARN("The master was restoring the db, retry later");
     } else {
-      error("Failed to get the db name, {}", line.get());
+      ERROR("Failed to get the db name, {}", line.get());
     }
     return CBState::RESTART;
   }
   std::string db_name = storage_->GetName();
   if (line.length == db_name.size() && !strncmp(line.get(), db_name.data(), line.length)) {
     // DB name match, we should continue to next step: TryPsync
-    info("[replication] DB name is valid, continue...");
+    INFO("[replication] DB name is valid, continue...");
     return CBState::NEXT;
   }
-  error("[replication] Mismatched the db name, local: {}, remote: {}", db_name, line.get());
+  ERROR("[replication] Mismatched the db name, local: {}, remote: {}", db_name, line.get());
   return CBState::RESTART;
 }
 
@@ -542,7 +567,7 @@ ReplicationThread::CBState ReplicationThread::replConfWriteCB(bufferevent *bev)
   }
   SendString(bev, redis::ArrayOfBulkStrings(data_to_send));
   repl_state_.store(kReplReplConf, std::memory_order_relaxed);
-  info("[replication] replconf request was sent, waiting for response");
+  INFO("[replication] replconf request was sent, waiting for response");
   return CBState::NEXT;
 }
 
@@ -554,20 +579,20 @@ ReplicationThread::CBState ReplicationThread::replConfReadCB(bufferevent *bev) {
   // on unknown option: first try without announce ip, if it fails again - do nothing (to prevent infinite loop)
   if (isUnknownOption(line.View()) && !next_try_without_announce_ip_address_) {
     next_try_without_announce_ip_address_ = true;
-    warn("The old version master, can't handle ip-address, try without it again");
+    WARN("The old version master, can't handle ip-address, try without it again");
     // Retry previous state, i.e. send replconf again
     return CBState::PREV;
   }
   if (line[0] == '-' && isRestoringError(line.View())) {
-    warn("The master was restoring the db, retry later");
+    WARN("The master was restoring the db, retry later");
     return CBState::RESTART;
   }
   if (!ResponseLineIsOK(line.View())) {
-    warn("[replication] Failed to replconf: {}", line.get() + 1);
+    WARN("[replication] Failed to replconf: {}", line.get() + 1);
     //  backward compatible with old version that doesn't support replconf cmd
     return CBState::NEXT;
   } else {
-    info("[replication] replconf is ok, start psync");
+    INFO("[replication] replconf is ok, start psync");
     return CBState::NEXT;
   }
 }
@@ -597,11 +622,11 @@ ReplicationThread::CBState ReplicationThread::tryPSyncWriteCB(bufferevent *bev)
   if (!srv_->GetConfig()->use_rsid_psync || next_try_old_psync_ || replid.length() != kReplIdLength) {
     next_try_old_psync_ = false;  // Reset next_try_old_psync_
     SendString(bev, redis::ArrayOfBulkStrings({"PSYNC", std::to_string(next_seq)}));
-    info("[replication] Try to use psync, next seq: {}", next_seq);
+    INFO("[replication] Try to use psync, next seq: {}", next_seq);
   } else {
     // NEW PSYNC "Unique Replication Sequence ID": replication id and sequence id
     SendString(bev, redis::ArrayOfBulkStrings({"PSYNC", replid, std::to_string(next_seq)}));
-    info("[replication] Try to use new psync, current unique replication sequence id: {}:{}", replid, cur_seq);
+    INFO("[replication] Try to use new psync, current unique replication sequence id: {}:{}", replid, cur_seq);
   }
   repl_state_.store(kReplSendPSync, std::memory_order_relaxed);
   return CBState::NEXT;
@@ -613,13 +638,13 @@ ReplicationThread::CBState ReplicationThread::tryPSyncReadCB(bufferevent *bev) {
   if (!line) return CBState::AGAIN;
 
   if (line[0] == '-' && isRestoringError(line.View())) {
-    warn("The master was restoring the db, retry later");
+    WARN("The master was restoring the db, retry later");
     return CBState::RESTART;
   }
 
   if (line[0] == '-' && isWrongPsyncNum(line.View())) {
     next_try_old_psync_ = true;
-    warn("The old version master, can't handle new PSYNC, try old PSYNC again");
+    WARN("The old version master, can't handle new PSYNC, try old PSYNC again");
     // Retry previous state, i.e. send PSYNC again
     return CBState::PREV;
   }
@@ -628,11 +653,12 @@ ReplicationThread::CBState ReplicationThread::tryPSyncReadCB(bufferevent *bev) {
     // PSYNC isn't OK, we should use FullSync
     // Switch to fullsync state machine
     fullsync_steps_.Start();
-    info("[replication] Failed to psync, error: {}, switch to fullsync", line.get());
+    INFO("[replication] Failed to psync, error: {}, switch to fullsync", line.get());
     return CBState::QUIT;
   } else {
     // PSYNC is OK, use IncrementBatchLoop
-    info("[replication] PSync is ok, start increment batch loop");
+    INFO("[replication] PSync is ok, start increment batch loop");
+    reconnect_attempts_.store(0, std::memory_order_relaxed);  // Reset backoff counter on successful connection
     return CBState::NEXT;
   }
 }
@@ -645,7 +671,7 @@ void ReplicationThread::sendReplConfAck(bufferevent *bev, bool force) {
     if (replication_group_sync_) {
       auto s = storage_->SyncWAL();
       if (!s.IsOK()) {
-        error("[replication] Failed to sync WAL before ack: {}", s.Msg());
+        ERROR("[replication] Failed to sync WAL before ack: {}", s.Msg());
         return;
       }
     }
@@ -688,7 +714,7 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
         }
         incr_bulk_len_ = line.length > 0 ? std::strtoull(line.get() + 1, nullptr, 10) : 0;
         if (incr_bulk_len_ == 0) {
-          error("[replication] Invalid increment data size");
+          ERROR("[replication] Invalid increment data size");
           return CBState::RESTART;
         }
         incr_state_ = Incr_batch_data;
@@ -734,7 +760,7 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
 
         auto s = storage_->ReplicaApplyWriteBatch(&batch, write_opts);
         if (!s.IsOK()) {
-          error("[replication] CRITICAL - Failed to write batch to local, {}. batch: 0x{}", s.Msg(),
+          ERROR("[replication] CRITICAL - Failed to write batch to local, {}. batch: 0x{}", s.Msg(),
                 util::StringToHex(batch.Data()));
           return CBState::RESTART;
         }
@@ -742,7 +768,7 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
 
         s = parseWriteBatch(batch);
         if (!s.IsOK()) {
-          error("[replication] CRITICAL - failed to parse write batch 0x{}: {}", util::StringToHex(batch.Data()),
+          ERROR("[replication] CRITICAL - failed to parse write batch 0x{}: {}", util::StringToHex(batch.Data()),
                 s.Msg());
           return CBState::RESTART;
         }
@@ -755,7 +781,7 @@ ReplicationThread::CBState ReplicationThread::incrementBatchLoopCB(bufferevent *
 ReplicationThread::CBState ReplicationThread::fullSyncWriteCB(bufferevent *bev) {
   SendString(bev, redis::ArrayOfBulkStrings({"_fetch_meta"}));
   repl_state_.store(kReplFetchMeta, std::memory_order_relaxed);
-  info("[replication] Start syncing data with fullsync");
+  INFO("[replication] Start syncing data with fullsync");
   return CBState::NEXT;
 }
 
@@ -771,31 +797,31 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
       UniqueEvbufReadln line(input, EVBUFFER_EOL_CRLF_STRICT);
       if (!line) return CBState::AGAIN;
       if (line[0] == '-') {
-        error("[replication] Failed to fetch meta id: {}", line.get());
+        ERROR("[replication] Failed to fetch meta id: {}", line.get());
         return CBState::RESTART;
       }
       fullsync_meta_id_ = static_cast<rocksdb::BackupID>(line.length > 0 ? std::strtoul(line.get(), nullptr, 10) : 0);
       if (fullsync_meta_id_ == 0) {
-        error("[replication] Invalid meta id received");
+        ERROR("[replication] Invalid meta id received");
         return CBState::RESTART;
       }
       fullsync_state_ = kFetchMetaSize;
-      info("[replication] Succeed fetching meta id: {}", fullsync_meta_id_);
+      INFO("[replication] Succeed fetching meta id: {}", fullsync_meta_id_);
     }
     case kFetchMetaSize: {
       UniqueEvbufReadln line(input, EVBUFFER_EOL_CRLF_STRICT);
       if (!line) return CBState::AGAIN;
       if (line[0] == '-') {
-        error("[replication] Failed to fetch meta size: {}", line.get());
+        ERROR("[replication] Failed to fetch meta size: {}", line.get());
         return CBState::RESTART;
       }
       fullsync_filesize_ = line.length > 0 ? std::strtoull(line.get(), nullptr, 10) : 0;
       if (fullsync_filesize_ == 0) {
-        error("[replication] Invalid meta file size received");
+        ERROR("[replication] Invalid meta file size received");
         return CBState::RESTART;
       }
       fullsync_state_ = kFetchMetaContent;
-      info("[replication] Succeed fetching meta size: {}", fullsync_filesize_);
+      INFO("[replication] Succeed fetching meta size: {}", fullsync_filesize_);
     }
     case kFetchMetaContent: {
       std::string target_dir;
@@ -807,7 +833,7 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         }
         auto s = engine::Storage::ReplDataManager::ParseMetaAndSave(storage_, fullsync_meta_id_, input, &meta);
         if (!s.IsOK()) {
-          error("[replication] Failed to parse meta and save: {}", s.Msg());
+          ERROR("[replication] Failed to parse meta and save: {}", s.Msg());
           return CBState::AGAIN;
         }
         target_dir = srv_->GetConfig()->backup_sync_dir;
@@ -816,7 +842,7 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         UniqueEvbufReadln line(input, EVBUFFER_EOL_CRLF_STRICT);
         if (!line) return CBState::AGAIN;
         if (line[0] == '-') {
-          error("[replication] Failed to fetch meta info: {}", line.get());
+          ERROR("[replication] Failed to fetch meta info: {}", line.get());
           return CBState::RESTART;
         }
         std::vector<std::string> need_files = util::Split(std::string(line.get()), ",");
@@ -832,17 +858,17 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         if (iter != need_files.end()) need_files.erase(iter);
         auto s = engine::Storage::ReplDataManager::CleanInvalidFiles(storage_, target_dir, need_files);
         if (!s.IsOK()) {
-          warn("[replication] Failed to clean up invalid files of the old checkpoint, error: {}", s.Msg());
-          warn("[replication] Try to clean all checkpoint files");
+          WARN("[replication] Failed to clean up invalid files of the old checkpoint, error: {}", s.Msg());
+          WARN("[replication] Try to clean all checkpoint files");
           auto s = rocksdb::DestroyDB(target_dir, rocksdb::Options());
           if (!s.ok()) {
-            warn("[replication] Failed to clean all checkpoint files, error: {}", s.ToString());
+            WARN("[replication] Failed to clean all checkpoint files, error: {}", s.ToString());
           }
         }
       }
       assert(evbuffer_get_length(input) == 0);
       fullsync_state_ = kFetchMetaID;
-      info("[replication] Succeeded fetching full data files info, fetching files in parallel");
+      INFO("[replication] Succeeded fetching full data files info, fetching files in parallel");
 
       bool pre_fullsync_done = false;
       // If 'slave-empty-db-before-fullsync' is yes, we call 'pre_fullsync_cb_'
@@ -858,10 +884,10 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
       auto s = parallelFetchFile(target_dir, meta.files);
       if (!s.IsOK()) {
         if (pre_fullsync_done) post_fullsync_cb_();
-        error("[replication] Failed to parallel fetch files while {}", s.Msg());
+        ERROR("[replication] Failed to parallel fetch files while {}", s.Msg());
         return CBState::RESTART;
       }
-      info("[replication] Succeeded fetching files in parallel, restoring the backup");
+      INFO("[replication] Succeeded fetching files in parallel, restoring the backup");
 
       // Don't need to call 'pre_fullsync_cb_' again if it was called before
       if (!pre_fullsync_done && !pre_fullsync_cb_()) return CBState::RESTART;
@@ -873,18 +899,19 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
         s = storage_->RestoreFromCheckpoint();
       }
       if (!s.IsOK()) {
-        error("[replication] Failed to restore backup while {}, restart fullsync", s.Msg());
+        ERROR("[replication] Failed to restore backup while {}, restart fullsync", s.Msg());
         post_fullsync_cb_();
         return CBState::RESTART;
       }
-      info("[replication] Succeeded restoring the backup, fullsync was finish");
+      INFO("[replication] Succeeded restoring the backup, fullsync was finish");
+      reconnect_attempts_.store(0, std::memory_order_relaxed);  // Reset backoff counter on successful fullsync
       post_fullsync_cb_();
 
       // It needs to reload namespaces from DB after the full sync is done,
       // or namespaces are not visible in the replica.
       s = srv_->GetNamespace()->LoadAndRewrite();
       if (!s.IsOK()) {
-        error("[replication] Failed to load and rewrite namespace: {}", s.Msg());
+        ERROR("[replication] Failed to load and rewrite namespace: {}", s.Msg());
       }
 
       // Switch to psync state machine again
@@ -892,7 +919,7 @@ ReplicationThread::CBState ReplicationThread::fullSyncReadCB(bufferevent *bev) {
       return CBState::QUIT;
     }
   }
-  unreachable();
+  UNREACHABLE();
 }
 
 Status ReplicationThread::parallelFetchFile(const std::string &dir,
@@ -943,7 +970,7 @@ Status ReplicationThread::parallelFetchFile(const std::string &dir,
               skip_cnt.fetch_add(1);
               uint32_t cur_skip_cnt = skip_cnt.load();
               uint32_t cur_fetch_cnt = fetch_cnt.load();
-              info("[skip] {} {}, skip count: {}, fetch count: {}, progress: {} / {}", f_name, f_crc, cur_skip_cnt,
+              INFO("[skip] {} {}, skip count: {}, fetch count: {}, progress: {} / {}", f_name, f_crc, cur_skip_cnt,
                    cur_fetch_cnt, (cur_skip_cnt + cur_fetch_cnt), files.size());
               continue;
             }
@@ -956,7 +983,7 @@ Status ReplicationThread::parallelFetchFile(const std::string &dir,
             fetch_cnt.fetch_add(1);
             uint32_t cur_skip_cnt = skip_cnt.load();
             uint32_t cur_fetch_cnt = fetch_cnt.load();
-            info("[fetch] Fetched {}, crc32 {}, skip count: {}, fetch count: {}, progress: {} / {}", fetch_file,
+            INFO("[fetch] Fetched {}, crc32 {}, skip count: {}, fetch count: {}, progress: {} / {}", fetch_file,
                  fetch_crc, cur_skip_cnt, cur_fetch_cnt, cur_skip_cnt + cur_fetch_cnt, files_count);
           };
           // For master using old version, it only supports to fetch a single file by one
@@ -1095,14 +1122,14 @@ Status ReplicationThread::fetchFiles(int sock_fd, const std::string &dir, const
 
   UniqueEvbuf evbuf;
   for (unsigned i = 0; i < files.size(); i++) {
-    debug("[fetch] Start to fetch file {}", files[i]);
+    DEBUG("[fetch] Start to fetch file {}", files[i]);
     s = fetchFile(sock_fd, evbuf.get(), dir, files[i], crcs[i], fn, ssl);
     if (!s.IsOK()) {
       s = Status(Status::NotOK, "fetch file err: " + s.Msg());
-      warn("[fetch] Fail to fetch file {}, err: {}", files[i], s.Msg());
+      WARN("[fetch] Fail to fetch file {}, err: {}", files[i], s.Msg());
       break;
     }
-    debug("[fetch] Succeed fetching file {}", files[i]);
+    DEBUG("[fetch] Succeed fetching file {}", files[i]);
 
     // Just for tests
     if (srv_->GetConfig()->fullsync_recv_file_delay) {
@@ -1116,7 +1143,7 @@ Status ReplicationThread::fetchFiles(int sock_fd, const std::string &dir, const
 void ReplicationThread::TimerCB(int, int16_t) {
   // DLOG(INFO) << "[replication] timer";
   if (stop_flag_) {
-    info("[replication] Stop ev loop");
+    INFO("[replication] Stop ev loop");
     event_base_loopbreak(base_);
     psync_steps_.Stop();
     fullsync_steps_.Stop();
