@@ -122,7 +122,7 @@ Status SlotMigrator::PerformSlotRangeMigration(const std::string &node_id, std::
     migration_job_ = std::move(job);
     job_cv_.notify_one();
   }
-  info("[migrate] Start migrating slot(s) {} to {}:{}", slot_range.String(), dst_ip, dst_port);
+  INFO("[migrate] Start migrating slot(s) {} to {}:{}", slot_range.String(), dst_ip, dst_port);
 
   return Status::OK();
 }
@@ -133,7 +133,7 @@ SlotMigrator::~SlotMigrator() {
     thread_state_ = ThreadState::Terminated;
     job_cv_.notify_all();
     if (auto s = util::ThreadJoin(t_); !s) {
-      warn("Slot migrating thread operation failed: {}", s.Msg());
+      WARN("Slot migrating thread operation failed: {}", s.Msg());
     }
   }
 }
@@ -158,7 +158,7 @@ void SlotMigrator::loop() {
       clean();
       return;
     }
-    info("[migrate] Migrating slot(s): {}, dst_ip: {}, dst_port: {}, max_speed: {}, max_pipeline_size: {}",
+    INFO("[migrate] Migrating slot(s): {}, dst_ip: {}, dst_port: {}, max_speed: {}, max_pipeline_size: {}",
          migration_job_->slot_range.String(), migration_job_->dst_ip, migration_job_->dst_port,
          migration_job_->max_speed, migration_job_->max_pipeline_size);
 
@@ -177,7 +177,7 @@ void SlotMigrator::runMigrationProcess() {
 
   while (true) {
     if (isTerminated()) {
-      warn("[migrate] Will stop state machine, because the thread was terminated");
+      WARN("[migrate] Will stop state machine, because the thread was terminated");
       clean();
       return;
     }
@@ -186,10 +186,10 @@ void SlotMigrator::runMigrationProcess() {
       case SlotMigrationStage::kStart: {
         auto s = startMigration();
         if (s.IsOK()) {
-          info("[migrate] Succeed to start migrating slot(s) {}", slot_range_.load().String());
+          INFO("[migrate] Succeed to start migrating slot(s) {}", slot_range_.load().String());
           current_stage_ = SlotMigrationStage::kSnapshot;
         } else {
-          error("[migrate] Failed to start migrating slot(s) {}. Error: {}", slot_range_.load().String(), s.Msg());
+          ERROR("[migrate] Failed to start migrating slot(s) {}. Error: {}", slot_range_.load().String(), s.Msg());
           current_stage_ = SlotMigrationStage::kFailed;
           resumeSyncCtx(s);
         }
@@ -200,7 +200,7 @@ void SlotMigrator::runMigrationProcess() {
         if (s.IsOK()) {
           current_stage_ = SlotMigrationStage::kWAL;
         } else {
-          error("[migrate] Failed to send snapshot of slot(s) {}. Error: {}", slot_range_.load().String(), s.Msg());
+          ERROR("[migrate] Failed to send snapshot of slot(s) {}. Error: {}", slot_range_.load().String(), s.Msg());
           current_stage_ = SlotMigrationStage::kFailed;
           resumeSyncCtx(s);
         }
@@ -209,10 +209,10 @@ void SlotMigrator::runMigrationProcess() {
       case SlotMigrationStage::kWAL: {
         auto s = syncWAL();
         if (s.IsOK()) {
-          info("[migrate] Succeed to sync from WAL for slot(s) {}", slot_range_.load().String());
+          INFO("[migrate] Succeed to sync from WAL for slot(s) {}", slot_range_.load().String());
           current_stage_ = SlotMigrationStage::kSuccess;
         } else {
-          error("[migrate] Failed to sync from WAL for slot(s) {}. Error: {}", slot_range_.load().String(), s.Msg());
+          ERROR("[migrate] Failed to sync from WAL for slot(s) {}. Error: {}", slot_range_.load().String(), s.Msg());
           current_stage_ = SlotMigrationStage::kFailed;
           resumeSyncCtx(s);
         }
@@ -221,12 +221,12 @@ void SlotMigrator::runMigrationProcess() {
       case SlotMigrationStage::kSuccess: {
         auto s = finishSuccessfulMigration();
         if (s.IsOK()) {
-          info("[migrate] Succeed to migrate slot(s) {}", slot_range_.load().String());
+          INFO("[migrate] Succeed to migrate slot(s) {}", slot_range_.load().String());
           current_stage_ = SlotMigrationStage::kClean;
           migration_state_ = MigrationState::kSuccess;
           resumeSyncCtx(s);
         } else {
-          error("[migrate] Failed to finish a successful migration of slot(s) {}. Error: {}",
+          ERROR("[migrate] Failed to finish a successful migration of slot(s) {}. Error: {}",
                 slot_range_.load().String(), s.Msg());
           current_stage_ = SlotMigrationStage::kFailed;
           resumeSyncCtx(s);
@@ -236,10 +236,10 @@ void SlotMigrator::runMigrationProcess() {
       case SlotMigrationStage::kFailed: {
         auto s = finishFailedMigration();
         if (!s.IsOK()) {
-          error("[migrate] Failed to finish a failed migration of slot(s) {}. Error: {}", slot_range_.load().String(),
+          ERROR("[migrate] Failed to finish a failed migration of slot(s) {}. Error: {}", slot_range_.load().String(),
                 s.Msg());
         }
-        info("[migrate] Failed to migrate a slot(s) {}", slot_range_.load().String());
+        INFO("[migrate] Failed to migrate a slot(s) {}", slot_range_.load().String());
         migration_state_ = MigrationState::kFailed;
         current_stage_ = SlotMigrationStage::kClean;
         break;
@@ -249,7 +249,7 @@ void SlotMigrator::runMigrationProcess() {
         return;
       }
       default:
-        error("[migrate] Unexpected state for the state machine: {}", static_cast<int>(current_stage_));
+        ERROR("[migrate] Unexpected state for the state machine: {}", static_cast<int>(current_stage_));
         clean();
         return;
     }
@@ -296,11 +296,11 @@ Status SlotMigrator::startMigration() {
   if (migration_type_ == MigrationType::kRawKeyValue) {
     bool supported = GET_OR_RET(supportedApplyBatchCommandOnDstNode(*dst_fd_));
     if (!supported) {
-      info("APPLYBATCH command is not supported, use redis command for migration");
+      INFO("APPLYBATCH command is not supported, use redis command for migration");
       migration_type_ = MigrationType::kRedisCommand;
     }
   }
-  info("[migrate] Start migrating slot(s) {}, connect destination fd {}", slot_range_.load().String(), *dst_fd_);
+  INFO("[migrate] Start migrating slot(s) {}, connect destination fd {}", slot_range_.load().String(), *dst_fd_);
 
   return Status::OK();
 }
@@ -329,11 +329,11 @@ Status SlotMigrator::sendSnapshotByCmd() {
   uint64_t empty_key_cnt = 0;
   std::string restore_cmds;
   SlotRange slot_range = slot_range_;
-  info("[migrate] Start migrating snapshot of slot(s): {}", slot_range.String());
+  INFO("[migrate] Start migrating snapshot of slot(s): {}", slot_range.String());
 
   // Construct key prefix to iterate the keys belong to the target slot
   std::string prefix = ComposeSlotKeyPrefix(namespace_, slot_range.start);
-  info("[migrate] Iterate keys of slot(s), key's prefix: {}", prefix);
+  INFO("[migrate] Iterate keys of slot(s), key's prefix: {}", prefix);
 
   std::string upper_bound = ComposeSlotKeyUpperBound(namespace_, slot_range.end);
   rocksdb::ReadOptions read_options = storage_->DefaultScanOptions();
@@ -370,23 +370,23 @@ Status SlotMigrator::sendSnapshotByCmd() {
     }
 
     if (*result == KeyMigrationResult::kMigrated) {
-      info("[migrate] The key {} successfully migrated", user_key);
+      INFO("[migrate] The key {} successfully migrated", user_key);
       migrated_key_cnt++;
     } else if (*result == KeyMigrationResult::kExpired) {
-      info("[migrate] The key {} is expired", user_key);
+      INFO("[migrate] The key {} is expired", user_key);
       expired_key_cnt++;
     } else if (*result == KeyMigrationResult::kUnderlyingStructEmpty) {
-      info("[migrate] The key {} has no elements", user_key);
+      INFO("[migrate] The key {} has no elements", user_key);
       empty_key_cnt++;
     } else {
-      error("[migrate] Migrated a key {} with unexpected result: {}", user_key, static_cast<int>(*result));
+      ERROR("[migrate] Migrated a key {} with unexpected result: {}", user_key, static_cast<int>(*result));
       return {Status::NotOK};
     }
   }
 
   if (auto s = iter->status(); !s.ok()) {
     auto err_str = s.ToString();
-    error("[migrate] Failed to iterate keys of slot {}: {}", current_slot, err_str);
+    ERROR("[migrate] Failed to iterate keys of slot {}: {}", current_slot, err_str);
     return {Status::NotOK, fmt::format("failed to iterate keys of slot {}: {}", current_slot, err_str)};
   }
 
@@ -396,7 +396,7 @@ Status SlotMigrator::sendSnapshotByCmd() {
   if (!s.IsOK()) {
     return s.Prefixed(errFailedToSendCommands);
   }
-  info(
+  INFO(
       "[migrate] Succeed to migrate slot(s) snapshot, slot(s): {}, Migrated keys: {}, Expired keys: {}, Empty keys: {}",
       slot_range.String(), migrated_key_cnt, expired_key_cnt, empty_key_cnt);
 
@@ -459,7 +459,7 @@ Status SlotMigrator::finishFailedMigration() {
 }
 
 void SlotMigrator::clean() {
-  info("[migrate] Clean resources of migrating slot(s) {}", slot_range_.load().String());
+  INFO("[migrate] Clean resources of migrating slot(s) {}", slot_range_.load().String());
   if (slot_snapshot_) {
     storage_->GetDB()->ReleaseSnapshot(slot_snapshot_);
     slot_snapshot_ = nullptr;
@@ -593,7 +593,7 @@ Status SlotMigrator::checkMultipleResponses(int sock_fd, int total) {
         case ParserState::ArrayLen: {
           UniqueEvbufReadln line(evbuf.get(), EVBUFFER_EOL_CRLF_STRICT);
           if (!line) {
-            info("[migrate] Event buffer is empty, read socket again");
+            INFO("[migrate] Event buffer is empty, read socket again");
             run = false;
             break;
           }
@@ -625,7 +625,7 @@ Status SlotMigrator::checkMultipleResponses(int sock_fd, int total) {
         // Handle bulk string response
         case ParserState::BulkData: {
           if (evbuffer_get_length(evbuf.get()) < bulk_or_array_len + 2) {
-            info("[migrate] Bulk data in event buffer is not complete, read socket again");
+            INFO("[migrate] Bulk data in event buffer is not complete, read socket again");
             run = false;
             break;
           }
@@ -639,7 +639,7 @@ Status SlotMigrator::checkMultipleResponses(int sock_fd, int total) {
           while (run && bulk_or_array_len > 0) {
             evbuffer_ptr ptr = evbuffer_search_eol(evbuf.get(), nullptr, nullptr, EVBUFFER_EOL_CRLF_STRICT);
             if (ptr.pos < 0) {
-              info("[migrate] Array data in event buffer is not complete, read socket again");
+              INFO("[migrate] Array data in event buffer is not complete, read socket again");
               run = false;
               break;
             }
@@ -1006,7 +1006,7 @@ Status SlotMigrator::sendCmdsPipelineIfNeed(std::string *commands, bool need) {
   }
 
   if (current_pipeline_size_ == 0) {
-    info("[migrate] No commands to send");
+    INFO("[migrate] No commands to send");
     return Status::OK();
   }
 
@@ -1032,7 +1032,7 @@ Status SlotMigrator::sendCmdsPipelineIfNeed(std::string *commands, bool need) {
 }
 
 void SlotMigrator::setForbiddenSlotRange(const SlotRange &slot_range) {
-  info("[migrate] Setting forbidden slot(s) {}", slot_range.String());
+  INFO("[migrate] Setting forbidden slot(s) {}", slot_range.String());
   // Block server to set forbidden slot
   uint64_t during = util::GetTimeStampUS();
   {
@@ -1040,11 +1040,11 @@ void SlotMigrator::setForbiddenSlotRange(const SlotRange &slot_range) {
     forbidden_slot_range_ = slot_range;
   }
   during = util::GetTimeStampUS() - during;
-  info("[migrate] To set forbidden slot, server was blocked for {} us", during);
+  INFO("[migrate] To set forbidden slot, server was blocked for {} us", during);
 }
 
 void SlotMigrator::ReleaseForbiddenSlotRange() {
-  info("[migrate] Release forbidden slot(s) {}", forbidden_slot_range_.load().String());
+  INFO("[migrate] Release forbidden slot(s) {}", forbidden_slot_range_.load().String());
   forbidden_slot_range_ = {-1, -1};
 }
 
@@ -1057,7 +1057,7 @@ void SlotMigrator::applyMigrationSpeedLimit() const {
     }
     if (last_send_time_ + per_request_time > current_time) {
       uint64_t during = last_send_time_ + per_request_time - current_time;
-      info("[migrate] Sleep to limit migration speed for: {}", during);
+      INFO("[migrate] Sleep to limit migration speed for: {}", during);
       std::this_thread::sleep_for(std::chrono::microseconds(during));
     }
   }
@@ -1068,7 +1068,7 @@ Status SlotMigrator::generateCmdsFromBatch(rocksdb::BatchResult *batch, std::str
   WriteBatchExtractor write_batch_extractor(storage_->IsSlotIdEncoded(), slot_range_, false);
   rocksdb::Status status = batch->writeBatchPtr->Iterate(&write_batch_extractor);
   if (!status.ok()) {
-    error("[migrate] Failed to parse write batch, Err: {}", status.ToString());
+    ERROR("[migrate] Failed to parse write batch, Err: {}", status.ToString());
     return {Status::NotOK};
   }
 
@@ -1086,7 +1086,7 @@ Status SlotMigrator::generateCmdsFromBatch(rocksdb::BatchResult *batch, std::str
 
 Status SlotMigrator::migrateIncrementData(std::unique_ptr<rocksdb::TransactionLogIterator> *iter, uint64_t end_seq) {
   if (!(*iter) || !(*iter)->Valid()) {
-    error("[migrate] WAL iterator is invalid");
+    ERROR("[migrate] WAL iterator is invalid");
     return {Status::NotOK};
   }
 
@@ -1095,13 +1095,13 @@ Status SlotMigrator::migrateIncrementData(std::unique_ptr<rocksdb::TransactionLo
 
   while (true) {
     if (stop_migration_) {
-      error("[migrate] Migration task end during migrating WAL data");
+      ERROR("[migrate] Migration task end during migrating WAL data");
       return {Status::NotOK};
     }
 
     auto batch = (*iter)->GetBatch();
     if (batch.sequence != next_seq) {
-      error("[migrate] WAL iterator is discrete, some seq might be lost, expected sequence: {}, but got sequence: {}",
+      ERROR("[migrate] WAL iterator is discrete, some seq might be lost, expected sequence: {}, but got sequence: {}",
             next_seq, batch.sequence);
       return {Status::NotOK};
     }
@@ -1109,26 +1109,26 @@ Status SlotMigrator::migrateIncrementData(std::unique_ptr<rocksdb::TransactionLo
     // Generate commands by iterating write batch
     auto s = generateCmdsFromBatch(&batch, &commands);
     if (!s.IsOK()) {
-      error("[migrate] Failed to generate commands from write batch");
+      ERROR("[migrate] Failed to generate commands from write batch");
       return {Status::NotOK};
     }
 
     // Check whether command pipeline should be sent
     s = sendCmdsPipelineIfNeed(&commands, false);
     if (!s.IsOK()) {
-      error("[migrate] Failed to send WAL commands pipeline");
+      ERROR("[migrate] Failed to send WAL commands pipeline");
       return {Status::NotOK};
     }
 
     next_seq = batch.sequence + batch.writeBatchPtr->Count();
     if (next_seq > end_seq) {
-      info("[migrate] Migrate incremental data an epoch OK, seq from {}, to {}", wal_begin_seq_, end_seq);
+      INFO("[migrate] Migrate incremental data an epoch OK, seq from {}, to {}", wal_begin_seq_, end_seq);
       break;
     }
 
     (*iter)->Next();
     if (!(*iter)->Valid()) {
-      error("[migrate] WAL iterator is invalid, expected end seq: {}, next seq: {}", end_seq, next_seq);
+      ERROR("[migrate] WAL iterator is invalid, expected end seq: {}, next seq: {}", end_seq, next_seq);
       return {Status::NotOK};
     }
   }
@@ -1136,7 +1136,7 @@ Status SlotMigrator::migrateIncrementData(std::unique_ptr<rocksdb::TransactionLo
   // Send the left data of this epoch
   auto s = sendCmdsPipelineIfNeed(&commands, true);
   if (!s.IsOK()) {
-    error("[migrate] Failed to send WAL last commands in pipeline");
+    ERROR("[migrate] Failed to send WAL last commands in pipeline");
     return {Status::NotOK};
   }
 
@@ -1150,7 +1150,7 @@ Status SlotMigrator::syncWalBeforeForbiddingSlot() {
     uint64_t latest_seq = storage_->GetDB()->GetLatestSequenceNumber();
     uint64_t gap = latest_seq - wal_begin_seq_;
     if (gap <= static_cast<uint64_t>(seq_gap_limit_)) {
-      info("[migrate] Incremental data sequence: {}, less than limit: {}, go to set forbidden slot", gap,
+      INFO("[migrate] Incremental data sequence: {}, less than limit: {}, go to set forbidden slot", gap,
            seq_gap_limit_);
       break;
     }
@@ -1158,21 +1158,21 @@ Status SlotMigrator::syncWalBeforeForbiddingSlot() {
     std::unique_ptr<rocksdb::TransactionLogIterator> iter = nullptr;
     auto s = storage_->GetWALIter(wal_begin_seq_ + 1, &iter);
     if (!s.IsOK()) {
-      error("[migrate] Failed to generate WAL iterator before setting forbidden slot, Err: {}", s.Msg());
+      ERROR("[migrate] Failed to generate WAL iterator before setting forbidden slot, Err: {}", s.Msg());
       return {Status::NotOK};
     }
 
     // Iterate wal and migrate data
     s = migrateIncrementData(&iter, latest_seq);
     if (!s.IsOK()) {
-      error("[migrate] Failed to migrate WAL data before setting forbidden slot");
+      ERROR("[migrate] Failed to migrate WAL data before setting forbidden slot");
       return {Status::NotOK};
     }
 
     wal_begin_seq_ = latest_seq;
     count++;
   }
-  info("[migrate] Succeed to migrate incremental data before setting forbidden slot, end epoch: {}", count);
+  INFO("[migrate] Succeed to migrate incremental data before setting forbidden slot, end epoch: {}", count);
   return Status::OK();
 }
 
@@ -1186,14 +1186,14 @@ Status SlotMigrator::syncWalAfterForbiddingSlot() {
   std::unique_ptr<rocksdb::TransactionLogIterator> iter = nullptr;
   auto s = storage_->GetWALIter(wal_begin_seq_ + 1, &iter);
   if (!s.IsOK()) {
-    error("[migrate] Failed to generate WAL iterator after setting forbidden slot, Err: {}", s.Msg());
+    ERROR("[migrate] Failed to generate WAL iterator after setting forbidden slot, Err: {}", s.Msg());
     return {Status::NotOK};
   }
 
   // Send incremental data
   s = migrateIncrementData(&iter, latest_seq);
   if (!s.IsOK()) {
-    error("[migrate] Failed to migrate WAL data after setting forbidden slot");
+    ERROR("[migrate] Failed to migrate WAL data after setting forbidden slot");
     return {Status::NotOK};
   }
 
@@ -1258,7 +1258,7 @@ Status SlotMigrator::sendMigrationBatch(BatchSender *batch) {
 Status SlotMigrator::sendSnapshotByRawKV() {
   uint64_t start_ts = util::GetTimeStampMS();
   auto slot_range = slot_range_.load();
-  info("[migrate] Migrating snapshot of slot(s) {} by raw key value", slot_range.String());
+  INFO("[migrate] Migrating snapshot of slot(s) {} by raw key value", slot_range.String());
 
   auto prefix = ComposeSlotKeyPrefix(namespace_, slot_range.start);
   auto upper_bound = ComposeSlotKeyUpperBound(namespace_, slot_range.end);
@@ -1326,7 +1326,7 @@ Status SlotMigrator::sendSnapshotByRawKV() {
   GET_OR_RET(sendMigrationBatch(&batch_sender));
 
   auto elapsed = util::GetTimeStampMS() - start_ts;
-  info(
+  INFO(
       "[migrate] Succeed to migrate snapshot range, slot(s): {}, elapsed: {} ms, sent: {} bytes, rate: {:.2f} kb/s, "
       "batches: {}, entries: {}",
       slot_range.String(), elapsed, batch_sender.GetSentBytes(), batch_sender.GetRate(start_ts),
@@ -1337,7 +1337,7 @@ Status SlotMigrator::sendSnapshotByRawKV() {
 
 Status SlotMigrator::syncWALByRawKV() {
   uint64_t start_ts = util::GetTimeStampMS();
-  info("[migrate] Syncing WAL of slot(s) {} by raw key value", slot_range_.load().String());
+  INFO("[migrate] Syncing WAL of slot(s) {} by raw key value", slot_range_.load().String());
   BatchSender batch_sender(*dst_fd_, migrate_batch_size_bytes_, migrate_batch_bytes_per_sec_);
 
   int epoch = 1;
@@ -1352,7 +1352,7 @@ Status SlotMigrator::syncWALByRawKV() {
     if (!s.IsOK()) {
       return {Status::NotOK, fmt::format("migrate incremental data failed, {}", s.Msg())};
     }
-    info("[migrate] Migrated incremental data, epoch: {}, seq from {} to {}", epoch, wal_begin_seq_,
+    INFO("[migrate] Migrated incremental data, epoch: {}, seq from {} to {}", epoch, wal_begin_seq_,
          wal_incremental_seq);
     wal_begin_seq_ = wal_incremental_seq;
     epoch++;
@@ -1366,12 +1366,12 @@ Status SlotMigrator::syncWALByRawKV() {
     if (!s.IsOK()) {
       return {Status::NotOK, fmt::format("migrate last incremental data failed, {}", s.Msg())};
     }
-    info("[migrate] Migrated last incremental data after set forbidden slot, seq from {} to {}", wal_begin_seq_,
+    INFO("[migrate] Migrated last incremental data after set forbidden slot, seq from {} to {}", wal_begin_seq_,
          wal_incremental_seq);
   }
 
   auto elapsed = util::GetTimeStampMS() - start_ts;
-  info(
+  INFO(
       "[migrate] Succeed to migrate incremental data, slot(s): {}, elapsed: {} ms, "
       "sent: {} bytes, rate: {:.2f} kb/s, batches: {}, entries: {}",
       slot_range_.load().String(), elapsed, batch_sender.GetSentBytes(), batch_sender.GetRate(start_ts),
@@ -1383,7 +1383,7 @@ Status SlotMigrator::syncWALByRawKV() {
 bool SlotMigrator::catchUpIncrementalWAL() {
   uint64_t gap = storage_->GetDB()->GetLatestSequenceNumber() - wal_begin_seq_;
   if (gap <= seq_gap_limit_) {
-    info("[migrate] Incremental data sequence gap: {}, less than limit: {}, set forbidden slot(s): {}", gap,
+    INFO("[migrate] Incremental data sequence gap: {}, less than limit: {}, set forbidden slot(s): {}", gap,
          seq_gap_limit_, slot_range_.load().String());
     return true;
   }
@@ -1405,7 +1405,7 @@ Status SlotMigrator::migrateIncrementalDataByRawKV(uint64_t end_seq, BatchSender
       }
       case engine::WALItem::Type::kTypePut: {
         if (item.column_family_id > kMaxColumnFamilyID) {
-          info("[migrate] Invalid put column family id: {}", item.column_family_id);
+          INFO("[migrate] Invalid put column family id: {}", item.column_family_id);
           continue;
         }
         GET_OR_RET(batch_sender->Put(storage_->GetCFHandle(static_cast<ColumnFamilyID>(item.column_family_id)),
@@ -1414,7 +1414,7 @@ Status SlotMigrator::migrateIncrementalDataByRawKV(uint64_t end_seq, BatchSender
       }
       case engine::WALItem::Type::kTypeDelete: {
         if (item.column_family_id > kMaxColumnFamilyID) {
-          info("[migrate] Invalid delete column family id: {}", item.column_family_id);
+          INFO("[migrate] Invalid delete column family id: {}", item.column_family_id);
           continue;
         }
         GET_OR_RET(
