@@ -75,12 +75,12 @@ class CommandScript : public Commander {
     if (args_.size() == 2 && subcommand_ == "flush") {
       auto s = srv->ScriptFlush();
       if (!s) {
-        error("Failed to flush scripts: {}", s.Msg());
+        ERROR("Failed to flush scripts: {}", s.Msg());
         return s;
       }
       s = srv->Propagate(engine::kPropagateScriptCommand, args_);
       if (!s) {
-        error("Failed to propagate script command: {}", s.Msg());
+        ERROR("Failed to propagate script command: {}", s.Msg());
         return s;
       }
       *output = redis::RESP_OK;
