@@ -26,6 +26,7 @@
 #include <string>
 
 #include "parse_util.h"
+#include "xxh3.h"
 
 namespace util {
 
@@ -556,4 +557,9 @@ std::string StringNext(std::string s) {
   return s;
 }
 
+std::string StringDigest(std::string_view s) {
+  XXH64_hash_t hash = XXH3_64bits(s.data(), s.size());
+  return fmt::format("{:016x}", hash);
+}
+
 }  // namespace util
