@@ -29,11 +29,13 @@
 namespace kqir {
 
 struct SortLimitFuse : Visitor {
+  std::string_view Name() override { return "SORTBY-LIMIT Fusion"; }
+
   std::unique_ptr<Node> Visit(std::unique_ptr<Limit> node) override {
     node = Node::MustAs<Limit>(Visitor::Visit(std::move(node)));
 
     if (auto sort = Node::As<Sort>(std::move(node->op))) {
-      return std::make_unique<TopNSort>(std::move(sort->op), std::move(sort->order), std::move(node->limit));
+      return std::make_unique<TopN>(std::move(sort->op), std::move(sort->order), std::move(node->limit));
     }
 
     return node;
