@@ -22,6 +22,7 @@
 
 #include "tls_util.h"
 
+#include <fmt/ostream.h>
 #include <openssl/err.h>
 #include <openssl/opensslv.h>
 #include <openssl/rand.h>
@@ -45,7 +46,7 @@ void InitSSL() {
   ERR_load_crypto_strings();
 
   if (!RAND_poll()) {
-    error("OpenSSL failed to generate random seed");
+    ERROR("OpenSSL failed to generate random seed");
     exit(1);
   }
 
@@ -117,19 +118,19 @@ StatusOr<unsigned long> ParseSSLProtocols(const std::string &protocols) {  // NO
 
 UniqueSSLContext CreateSSLContext(const Config *config, const SSL_METHOD *method) {
   if (config->tls_cert_file.empty() || config->tls_key_file.empty()) {
-    error("Both tls-cert-file and tls-key-file must be specified while TLS is enabled");
+    ERROR("Both tls-cert-file and tls-key-file must be specified while TLS is enabled");
     return nullptr;
   }
 
   auto ssl_ctx = UniqueSSLContext(method);
   if (!ssl_ctx) {
-    error("Failed to construct SSL context: {}", fmt::streamed(SSLErrors{}));
+    ERROR("Failed to construct SSL context: {}", fmt::streamed(SSLErrors{}));
     return nullptr;
   }
 
   auto proto_status = ParseSSLProtocols(config->tls_protocols);
   if (!proto_status) {
-    error("{}", proto_status.Msg());
+    ERROR("{}", proto_status.Msg());
     return nullptr;
   }
 
@@ -176,16 +177,16 @@ UniqueSSLContext CreateSSLContext(const Config *config, const SSL_METHOD *method
   auto ca_dir = config->tls_ca_cert_dir.empty() ? nullptr : config->tls_ca_cert_dir.c_str();
   if (ca_file || ca_dir) {
     if (SSL_CTX_load_verify_locations(ssl_ctx.get(), ca_file, ca_dir) != 1) {
-      error("Failed to load CA certificates: {}", fmt::streamed(SSLErrors{}));
+      ERROR("Failed to load CA certificates: {}", fmt::streamed(SSLErrors{}));
       return nullptr;
     }
   } else if (config->tls_auth_clients != TLS_AUTH_CLIENTS_NO) {
-    error("Either tls-ca-cert-file or tls-ca-cert-dir must be specified while tls-auth-clients is enabled");
+    ERROR("Either tls-ca-cert-file or tls-ca-cert-dir must be specified while tls-auth-clients is enabled");
     return nullptr;
   }
 
   if (SSL_CTX_use_certificate_chain_file(ssl_ctx.get(), config->tls_cert_file.c_str()) != 1) {
-    error("Failed to load SSL certificate file: {}", fmt::streamed(SSLErrors{}));
+    ERROR("Failed to load SSL certificate file: {}", fmt::streamed(SSLErrors{}));
     return nullptr;
   }
 
@@ -199,23 +200,23 @@ UniqueSSLContext CreateSSLContext(const Config *config, const SSL_METHOD *method
   }
 
   if (SSL_CTX_use_PrivateKey_file(ssl_ctx.get(), config->tls_key_file.c_str(), SSL_FILETYPE_PEM) != 1) {
-    error("Failed to load SSL private key file: {}", fmt::streamed(SSLErrors{}));
+    ERROR("Failed to load SSL private key file: {}", fmt::streamed(SSLErrors{}));
     return nullptr;
   }
 
   if (SSL_CTX_check_private_key(ssl_ctx.get()) != 1) {
-    error("Failed to check the loaded private key: {}", fmt::streamed(SSLErrors{}));
+    ERROR("Failed to check the loaded private key: {}", fmt::streamed(SSLErrors{}));
     return nullptr;
   }
 
   if (!config->tls_ciphers.empty() && !SSL_CTX_set_cipher_list(ssl_ctx.get(), config->tls_ciphers.c_str())) {
-    error("Failed to set SSL ciphers: {}", fmt::streamed(SSLErrors{}));
+    ERROR("Failed to set SSL ciphers: {}", fmt::streamed(SSLErrors{}));
     return nullptr;
   }
 
 #ifdef SSL_OP_NO_TLSv1_3
   if (!config->tls_ciphersuites.empty() && !SSL_CTX_set_ciphersuites(ssl_ctx.get(), config->tls_ciphersuites.c_str())) {
-    error("Failed to set SSL ciphersuites: {}", fmt::streamed(SSLErrors{}));
+    ERROR("Failed to set SSL ciphersuites: {}", fmt::streamed(SSLErrors{}));
     return nullptr;
   }
 #endif
