@@ -37,7 +37,7 @@ void WriteBatchExtractor::LogData(const rocksdb::Slice &blob) {
   } else {
     // Redis type log data
     if (auto s = log_data_.Decode(blob); !s.IsOK()) {
-      warn("Failed to decode Redis type log: {}", s.Msg());
+      WARN("Failed to decode Redis type log: {}", s.Msg());
     }
   }
 }
@@ -139,7 +139,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
       case kRedisList: {
         auto args = log_data_.GetArguments();
         if (args->empty()) {
-          error("Failed to parse write_batch in PutCF. Type=List: no arguments, at least should contain a command");
+          ERROR("Failed to parse write_batch in PutCF. Type=List: no arguments, at least should contain a command");
           return rocksdb::Status::OK();
         }
 
@@ -153,7 +153,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
         switch (cmd) {
           case kRedisCmdLSet:
             if (args->size() < 2) {
-              error(
+              ERROR(
                   "Failed to parse write_batch in PutCF. Command=LSET: no enough arguments, at least should contain an "
                   "index");
               return rocksdb::Status::OK();
@@ -164,7 +164,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
           case kRedisCmdLInsert:
             if (first_seen_) {
               if (args->size() < 4) {
-                error(
+                ERROR(
                     "Failed to parse write_batch in PutCF. Command=LINSERT: no enough arguments, should contain before "
                     "pivot values");
                 return rocksdb::Status::OK();
@@ -187,7 +187,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
             // LMOVE will be parsed in DeleteCF, so ignore it here
             break;
           default:
-            error("Failed to parse write_batch in PutCF. Type=List: unhandled command with code {}", *parse_result);
+            ERROR("Failed to parse write_batch in PutCF. Type=List: unhandled command with code {}", *parse_result);
         }
         break;
       }
@@ -202,7 +202,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
       case kRedisBitmap: {
         auto args = log_data_.GetArguments();
         if (args->empty()) {
-          error("Failed to parse write_batch in PutCF. Type=Bitmap: no arguments, at least should contain a command");
+          ERROR("Failed to parse write_batch in PutCF. Type=Bitmap: no arguments, at least should contain a command");
           return rocksdb::Status::OK();
         }
 
@@ -216,7 +216,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
         switch (cmd) {
           case kRedisCmdSetBit: {
             if (args->size() < 2) {
-              error(
+              ERROR(
                   "Failed to parse write_batch in PutCF. Command=SETBIT: no enough arguments, should contain an "
                   "offset");
               return rocksdb::Status::OK();
@@ -234,7 +234,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
           case kRedisCmdBitOp:
             if (first_seen_) {
               if (args->size() < 4) {
-                error(
+                ERROR(
                     "Failed to parse write_batch in PutCF. Command=BITOP: no enough arguments, at least should contain "
                     "srckey");
                 return rocksdb::Status::OK();
@@ -250,7 +250,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
             command_args.insert(command_args.end(), args->begin() + 1, args->end());
             break;
           default:
-            error("Failed to parse write_batch in PutCF. Type=Bitmap: unhandled command with code {}", *parsed_cmd);
+            ERROR("Failed to parse write_batch in PutCF. Type=Bitmap: unhandled command with code {}", *parsed_cmd);
             return rocksdb::Status::OK();
         }
         break;
@@ -268,7 +268,7 @@ rocksdb::Status WriteBatchExtractor::PutCF(uint32_t column_family_id, const Slic
   } else if (column_family_id == static_cast<uint32_t>(ColumnFamilyID::Stream)) {
     auto s = ExtractStreamAddCommand(is_slot_id_encoded_, key, value, &command_args);
     if (!s.IsOK()) {
-      error("Failed to parse write_batch in PutCF. Type=Stream: {}", s.Msg());
+      ERROR("Failed to parse write_batch in PutCF. Type=Stream: {}", s.Msg());
       return rocksdb::Status::OK();
     }
   }
@@ -322,7 +322,7 @@ rocksdb::Status WriteBatchExtractor::DeleteCF(uint32_t column_family_id, const S
       case kRedisList: {
         auto args = log_data_.GetArguments();
         if (args->empty()) {
-          error("Failed to parse write_batch in DeleteCF. Type=List: no arguments, at least should contain a command");
+          ERROR("Failed to parse write_batch in DeleteCF. Type=List: no arguments, at least should contain a command");
           return rocksdb::Status::OK();
         }
 
@@ -337,7 +337,7 @@ rocksdb::Status WriteBatchExtractor::DeleteCF(uint32_t column_family_id, const S
           case kRedisCmdLTrim:
             if (first_seen_) {
               if (args->size() < 3) {
-                error(
+                ERROR(
                     "Failed to parse write_batch in DeleteCF; Command=LTRIM: no enough arguments, should contain start "
                     "and stop");
                 return rocksdb::Status::OK();
@@ -350,7 +350,7 @@ rocksdb::Status WriteBatchExtractor::DeleteCF(uint32_t column_family_id, const S
           case kRedisCmdLRem:
             if (first_seen_) {
               if (args->size() < 3) {
-                error(
+                ERROR(
                     "Failed to parse write_batch in DeleteCF. Command=LREM: no enough arguments, should "
                     "contain count and value");
                 return rocksdb::Status::OK();
@@ -369,7 +369,7 @@ rocksdb::Status WriteBatchExtractor::DeleteCF(uint32_t column_family_id, const S
           case kRedisCmdLMove:
             if (first_seen_) {
               if (args->size() < 5) {
-                error(
+                ERROR(
                     "Failed to parse write_batch in DeleteCF; Command=LMOVE: no enough arguments, should "
                     "contain source, destination and where/from arguments");
                 return rocksdb::Status::OK();
@@ -379,7 +379,7 @@ rocksdb::Status WriteBatchExtractor::DeleteCF(uint32_t column_family_id, const S
             }
             break;
           default:
-            error("Failed to parse write_batch in DeleteCF. Type=List: unhandled command with code {}", *parse_result);
+            ERROR("Failed to parse write_batch in DeleteCF. Type=List: unhandled command with code {}", *parse_result);
         }
         break;
       }
