@@ -73,7 +73,9 @@ func (s *KvrocksServer) TLSAddr() string {
 
 func (s *KvrocksServer) LogFileMatches(t testing.TB, pattern string) bool {
 	dir := s.configs["dir"]
-	content, err := os.ReadFile(dir + "/kvrocks.INFO")
+	now := time.Now()
+	filename := dir + fmt.Sprintf("/kvrocks_%d-%02d-%02d.log", now.Year(), now.Month(), now.Day())
+	content, err := os.ReadFile(filename)
 	require.NoError(t, err)
 	p := regexp.MustCompile(pattern)
 	return p.Match(content)
@@ -242,7 +244,7 @@ func StartServerWithCLIOptions(
 		defer func() { require.NoError(t, f.Close()) }()
 
 		for k := range configs {
-			_, err := f.WriteString(fmt.Sprintf("%s %s\n", k, configs[k]))
+			_, err := fmt.Fprintf(f, "%s %s\n", k, configs[k])
 			require.NoError(t, err)
 		}
 		cmd.Args = append(cmd.Args, "-c", f.Name())
